@@ -1,23 +1,23 @@
 <?php echo '<?xml version="1.0" encoding="utf-8"?>' ."\n" ?>
-<!--
-## (c)2003-2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
-##
-##  $Id: weather.php,v 1.1 2006/11/24 08:57:53 nishi Exp $
-##
-##  http://hil.t.u-tokyo.ac.jp/~nishi/galatea-php/weather.php
-##
--->
 <?php mb_http_output('utf-8') ?>
+<!--
+## (c)2003-2007 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
+##  $Id: weather.php,v 1.2 2007/08/09 02:26:41 nishi Exp $
+-->
 
 <vxml version="2.0" xml:lang="ja">
 
-<?php if(isset($_REQUEST['region']) && $_REQUEST['region'] != '') { ?>
+<?php
+if(isset($_REQUEST['region']) && $_REQUEST['region'] != '') {
+   $region = $_REQUEST['region'];
+   mb_convert_variables("UTF-8", mb_detect_encoding($region), $region);
+?>
 <form id="answer">
   <block>
-    <log>地域：<?php echo $_REQUEST['region'] ?>，今日：晴れ，明日：曇り</log>
+    <log>地域：<?php echo $region ?>，今日：晴れ，明日：曇り</log>
     <prompt>
       天気予報です。
-      <?php echo $_REQUEST['region'] ?>の、
+      <?php echo $region ?>の、
       今日の天気は晴れです。
       明日は曇りです。
       <break/>
@@ -27,7 +27,6 @@
 </form>
 <?php } ?>
 
-
 <form id="ask">
   <field name="region">
    <prompt timeout="20s"> 
@@ -45,7 +44,7 @@
    </grammar>
   </field>
   <block>
-    <submit next="weather.php"/> <!-- this file -->
+    <submit next="<?php echo basename(__FILE__) ?>"/> 
   </block>
 </form>
 
