@@ -3,7 +3,7 @@
  * Galatea Dialog Manager:
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- *  $Id: DialogManager.java,v 1.31 2008/02/14 03:35:39 nishi Exp $
+ *  $Id: DialogManager.java,v 1.32 2008/04/09 10:06:53 nishi Exp $
  */
 
 package galatea.dialog;
@@ -47,7 +47,7 @@ public class DialogManager {
 	private IInteractionController interactionController_;
 	private IControllerModeManager modeManager_;
 	private String filename;
-	private String poststring;
+	private String poststring = "";
 	
 	/**
 	 * @param res
@@ -153,6 +153,15 @@ public class DialogManager {
 			filename = Util.getNormalizedFileName(filename);
 		}
 		
+		// 
+		String workdir = Property.getForPlatformAsStr("Grammar.WorkDir", "/tmp");
+		File file = new File(workdir);
+		if (!file.exists()) {
+			file.mkdir();
+			//System.err.println("no directory : " + workdir);
+			//System.exit(0);
+		}
+
 		theIC_ = new IC();
 		theIC_.start();
 		if ( Property.getAsBoolean("ShowVersion", true) ) {
@@ -197,9 +206,7 @@ public class DialogManager {
 					interactionController_.setStateMap(stateMap);
 					String state = "[Load] " + filename + " [post] " + poststring;
 					String src = loader.getSrcAsString();
-					String trans = 
-						// loader.getWarnings() + "\n" + 
-						loader.getTranslatedAsString();
+					String trans = loader.getTranslatedAsString();
 					interactionController_.dispDocInfo(filename, state, src, trans);
 				} else {
 					dbg.print("StatelessMode=true");
@@ -210,35 +217,11 @@ public class DialogManager {
 				filename = interactionController_.getNextDocFile();
 				poststring = interactionController_.getPostString();
 				interactionController_.resetNextDocFile();
-//			} catch(java.io.FileNotFoundException e){
-//				System.err.println("caught " + e.toString());
-//				modeManager_.setStatelessMode(true);
-//				modeManager_.setPauseMode(true);
-//				interactionController_.dispDocInfo("", "(stateless)", "", "");
-//				interactionController_.resetNextDocFile();
-//				filename = "";
-//			} catch(org.xml.sax.SAXParseException e){
-//				System.err.println("caught " + e.toString());
-//				interactionController_.resetNextDocFile();
-//			} catch(galatea.document.DocError e){
-//				System.err.println("caught " + e.toString());
-//				modeManager_.setStatelessMode(true);
-//				modeManager_.setPauseMode(true);
-//				interactionController_.dispDocInfo("", "(stateless)", "", "");
-//				interactionController_.resetNextDocFile();
-//			} catch(galatea.dialog.RuntimeError e){
-//				System.err.println("caught " + e.toString());
-//				modeManager_.setStatelessMode(true);
-//				modeManager_.setPauseMode(true);
-//				interactionController_.dispDocInfo("", "(stateless)", "", "");
-//				interactionController_.resetNextDocFile();
 			} catch(java.lang.Exception e){
-//				System.err.println("caught " + e.toString());
-//				interactionController_.resetNextDocFile();
 				System.err.println("caught " + e.toString());
 				modeManager_.setStatelessMode(true);
 				modeManager_.setPauseMode(true);
-				interactionController_.dispDocInfo("", "(no dialog)", "", "");
+				interactionController_.dispDocInfo("", e.toString(), "", "");
 				interactionController_.resetNextDocFile();
 				filename = "";
 			}
