@@ -1,11 +1,12 @@
 /*
  * Galatea Dialog Manager:
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
- * $Id: ICommandContext.java,v 1.2 2006/12/08 04:09:05 nishi Exp $
+ * $Id: ICommandContext.java,v 1.4 2008/02/13 03:47:25 nishi Exp $
  */
 
 package galatea.dialog;
 
+import galatea.command.Command;
 import galatea.outitem.OutItem;
 
 import java.util.ArrayList;
@@ -13,11 +14,11 @@ import java.util.ArrayList;
 public interface ICommandContext
 {
     public void enqueueOutItem(OutItem oi);
-    public void insertCommandsTop(ArrayList v);
+    public void insertCommandsTop(ArrayList<Command> v);
     public void setEndFlag(boolean b);
     public void setEndImm(boolean b);
-    public void setNextDocFile(String s);
     public void gotoState(String state);
     public void setNextState(String state);
     public void stopOutput();
+	public void setNextDocFile(String nextfile, String post);
 }
