@@ -2,21 +2,21 @@
  * Galatea Dialog Manager:
  * (c)2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: InterpretedEventQueueManager.java,v 1.1 2006/11/20 01:13:35 nishi Exp $
+ * $Id: InterpretedEventQueueManager.java,v 1.3 2008/02/14 02:00:07 nishi Exp $
  */
 package galatea.dialog;
 
 
-import galatea.util.Logger;
+import galatea.logger.Logger;
 
 import java.util.ArrayList;
 
 public class InterpretedEventQueueManager {
 	private Logger dbg = new Logger("InterpretedEventQueueManager", 0);
-	private ArrayList queue_; // ArrayList<InterpretedEvent>
+	private ArrayList<InterpretedEvent> queue_; // ArrayList<InterpretedEvent>
 	
 	public InterpretedEventQueueManager() {
-		queue_ = new ArrayList();
+		queue_ = new ArrayList<InterpretedEvent>();
 	}
 	
 	public synchronized void discard() {
@@ -24,7 +24,7 @@ public class InterpretedEventQueueManager {
 	}
 	
 	public synchronized void enqueue(InterpretedEvent o) {
-		queue_.add((Object)o);
+		queue_.add(o);
 		dbg.print("EQM: added " + o.getClass().getName() 
 				+ ", total:" + queue_.size() );
 	}
