@@ -2,7 +2,7 @@ package galatea.dialog;
 public class Tstamp
 { 
 	public static final String TSTAMP = 
-		"Galatea Dialog Studio 2.2.1 (080216)";
+		"Galatea Dialog Studio 2.2.2.2 (080817)";
 	
 	public static final String COPYRIGHT = 
 		"(c)2003-2008 Takuya NISHIMOTO (nishimoto@m.ieice.org)";
@@ -30,6 +30,10 @@ public class Tstamp
 	 * Ver 2.1.2.0 (080214) : bug fix on Linux
 	 * Ver 2.1.2.1 (080214) : includes (again) js.jar
 	 * Ver 2.2.1   (080216) : UseMozillaRhino=1
+	 * Ver 2.2.1.2 (080409) : Use mkdfa.exe as default, create c:/tmp if not exist
+	 * Ver 2.2.2   (080501) : mkdfa.pl as default again, SubProcess fix, sort config 
+	 * Ver 2.2.2.1 (080815) : _fromSRMtell() hack for julius-4.0.2  
+	 * Ver 2.2.2.2 (080817) : NetUtil loadXMLFile / sleep at _gotoRunLevel2  
 	 */
 }
 
