@@ -763,7 +763,6 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 			}
 		}
 		
-		
 		public boolean enter(VxmlForm vxmlForm) {
 			String dialogId = vxmlForm.getId();
 			if (dialogId == null) dialogId = "";
@@ -2043,9 +2042,9 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 		
 		public boolean enter(VxmlSubmit e) {
 			String post = "";
-			boolean isPost = false;
-			if (e.getMethod() != null && e.getMethod().toLowerCase().equals("post") ) {
-				isPost = true;
+			boolean isPost = true;
+			if (e.getMethod() != null && e.getMethod().toLowerCase().equals("get") ) {
+				isPost = false;
 			}
 			
 			String script = "";
@@ -2069,7 +2068,13 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 						} else {
 							post += "+'&'";
 						}
-						post += "'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
+						//post += "'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
+						String k = submitItems_.getKey(i);
+						if (k == null) {
+							docErrors_.add(new DocError("submit post : <field> or <var> has no NAME."));
+							return false;
+						}
+						post += "'" + k + "='+" + k;
 					}
 				} else {
 					names = namelist.split(" ");
@@ -2094,7 +2099,13 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 						} else {
 							script += "+'&'";
 						}
-						script += "+'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
+						// script += "+'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
+						String k = submitItems_.getKey(i);
+						if (k == null) {
+							docErrors_.add(new DocError("submit get : <field> or <var> has no NAME."));
+							return false;
+						}
+						script += "+'" + k + "='+" + k;
 					}
 				} else {
 					names = namelist.split(" ");
