@@ -2,7 +2,7 @@
  * Galatea Dialog Manager:
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: GrammarTransformer.java,v 1.13 2008/02/14 02:00:07 nishi Exp $
+ * $Id: GrammarTransformer.java,v 1.14 2008/04/09 10:26:06 nishi Exp $
  */
 package galatea.grammar;
 
@@ -36,9 +36,11 @@ public class GrammarTransformer {
 //	private String exception_ = "";
 	private SubProcess subProcess_;
 	private String mkdfaPerl_ = "perl";
-	private String mkdfaExe_ = "./mkdfa.pl";
+	private String mkdfaScript_ = "./mkdfa.pl";
 	private String mkdfaDir_ = ".";
 	private boolean running_ = false;
+	private String mkdfaExe_;
+	private boolean useMkdfaExe_ = false;
 	private static int count_ = 0;
 
 	public static void main(String argv[]) {
@@ -74,9 +76,13 @@ public class GrammarTransformer {
 				"Grammar.Mkdfa.Dir", 
 				"/data/istc-cdrom-2006-10/linux/bin/SRM/bin"
 				);
+		mkdfaScript_ = Property.getForPlatformAsStr(
+				"Grammar.Mkdfa.Script", 
+				"mkdfa.pl");
 		mkdfaExe_ = Property.getForPlatformAsStr(
 				"Grammar.Mkdfa.Exe", 
-				"mkdfa.pl");
+				"mkdfa.exe");
+		useMkdfaExe_  = Property.getForPlatformAsBoolean("Grammar.UseMkdfaExe", true);
 		
 		if (count_ == 0) {
 			Runtime.getRuntime().addShutdownHook(new Thread() {
@@ -111,7 +117,7 @@ public class GrammarTransformer {
 	}
 	
 	private boolean _generate_ORG(String base) {
-		subProcess_ = new SubProcess(mkdfaDir_ + "/" + mkdfaExe_ + " " + base);
+		subProcess_ = new SubProcess(mkdfaDir_ + "/" + mkdfaScript_ + " " + base);
 		if (subProcess_ == null) {
 			return false;
 		}
@@ -181,8 +187,12 @@ public class GrammarTransformer {
 //		exception_ = "";
 		errors_ = "";
 		outputs_ = "";
-		String cmd = mkdfaPerl_ + " " + mkdfaDir_ + "/" + mkdfaExe_ + " " + base;
-		//String cmd = mkdfaExe_ + " " + base;
+		String cmd = "";
+		if (useMkdfaExe_) {
+			cmd = mkdfaDir_ + "/" + mkdfaExe_ + " " + base;
+		} else {
+			cmd = mkdfaPerl_ + " " + mkdfaDir_ + "/" + mkdfaScript_ + " " + base;
+		}
 		String dir = mkdfaDir_;
 		base = Util.getPlatformFileName(base);
 		cmd = Util.getPlatformFileName(cmd); 
