@@ -238,17 +238,17 @@ public class DeviceManager
 	}
 
 	private boolean _gotoRunLevel2() {
-//		// これを実行しないと runLevel=2 に移行しない
-//		String scfile = Property.getAsStr("DM.SubmoduleConfigFile", null);
-//		if (scfile != null) {
-//			_loadSubmoduleConfigFile(scfile);
-//			_outputNative(initOutputCmd_);
-//			_outputNative(initRecogCmd_);
-//		}
 		setRunLevel(1);
 		_dispDeviceManagerLog("RunLevel:1");
 		amt_.outputNative("rep Run = DEAD");
 		
+		// wait for the wakeup of SRM (julius4)
+		try { 
+			Thread.sleep(2, 0);
+		} catch (Exception e) {
+			e.printStackTrace();
+		}
+		
 		_setTargetRunLevel(2);
 		return true;
 	}
