@@ -134,11 +134,17 @@ public class JulianSubModule
 			logger_.inputEventReceived(s);
 			return;
 		}
-		if (s.startsWith("<STARTPROC/>")) {
+
+		// for julius-4
+		// see also galatea.io.wrapper.SRMSubModule#_fromSRMtell()
+		if (s.startsWith("<STARTPROC/>") 
+			|| s.startsWith("<ENDPROC/>") 
+			|| s.startsWith("<STARTRECOG/>") 
+			|| s.startsWith("<ENDRECOG/>")) {
 			logger_.inputEventReceived(s);
-			receiver_.receiveRunLevel(2, this);
 			return;
 		}
+
 		if (s.startsWith("<GMM ")) {
 			logger_.inputEventReceived(s);
 			return;
@@ -233,7 +239,13 @@ public class JulianSubModule
 			setSlotAlias(s);
 			return true;
 		} else if ((s = Util.getFirstGroup("to @SRM set Grammar = (.*)$", str)) != null) {
-			sendGrammar(s);
+			try {
+				sendGrammar(s);
+			} catch (Exception e) {
+				// TODO: handle severe error
+				logger_.grammarFileUpdated(e.toString());
+				return true;
+			}
 			logger_.grammarFileUpdated(getGrammarForDisplay(s));
 			return true;
 		} else if (str.startsWith("to @SRM set Dic =")) {
@@ -242,22 +254,31 @@ public class JulianSubModule
 		return false;
 	}
 	
-	public void sendGrammar(String s) {
+	public void sendGrammar(String s) throws Exception {
 		String file = s.replaceAll(".dfa", "");
 		Charset charset_ = Util.getSystemDefaultCharset();
-		try {
-			String dfa  = Util.loadFromFile(file + ".dfa",  charset_);
-			String dict = Util.loadFromFile(file + ".dict", charset_);
-			client_.send("CHANGEGRAM " + file + "\n");
-			client_.send(dfa);
-			client_.send("DFAEND\n");
-			client_.send(dict);
-			client_.send("DICEND\n");
-			// TODO: wait <GRAMMAR STATUS="RECEIVED"/>
-			client_.send("RESUME\n");
-		} catch (Exception e) {
-			e.printStackTrace();
-		}
+//		try {
+//			String dfa  = Util.loadFromFile(file + ".dfa",  charset_);
+//			String dict = Util.loadFromFile(file + ".dict", charset_);
+//			client_.send("CHANGEGRAM " + file + "\n");
+//			client_.send(dfa);
+//			client_.send("DFAEND\n");
+//			client_.send(dict);
+//			client_.send("DICEND\n");
+//			// TODO: wait <GRAMMAR STATUS="RECEIVED"/>
+//			client_.send("RESUME\n");
+//		} catch (Exception e) {
+//			e.printStackTrace();
+//		}
+		String dfa  = Util.loadFromFile(file + ".dfa",  charset_);
+		String dict = Util.loadFromFile(file + ".dict", charset_);
+		client_.send("CHANGEGRAM " + file + "\n");
+		client_.send(dfa);
+		client_.send("DFAEND\n");
+		client_.send(dict);
+		client_.send("DICEND\n");
+		// TODO: wait <GRAMMAR STATUS="RECEIVED"/>
+		client_.send("RESUME\n");
 	}
 	
 	public String getGrammarForDisplay(String s) {
