@@ -73,6 +73,15 @@ implements RecogInterpreterListener
 	private void _fromSRMtell(String s) {
 		_debugPrint("[" + xmlContent_ + "] [" + s + "]");
 		
+		// for julius-4
+		if (s.startsWith("<STARTPROC/>") 
+			|| s.startsWith("<ENDPROC/>") 
+			|| s.startsWith("<STARTRECOG/>") 
+			|| s.startsWith("<ENDRECOG/>")) {
+			logger_.inputEventReceived(s);
+			return;
+		}
+
 		if (s.startsWith("grammar ")) {
 			logger_.inputEventReceived(s);
 			return;
