@@ -37,17 +37,22 @@ public class JuliusClient
 	}
 	
 	
-	public void send(String str) 
+	public void send(String str) throws IOException 
 	{
-		try {
-			byteBuffer.clear();
-			encoder.reset();
-			encoder.encode(CharBuffer.wrap(str), byteBuffer, true);
-			byteBuffer.flip();
-			channel.write(byteBuffer);
-		} catch (IOException ex) {
-			ex.printStackTrace();
-		}
+		byteBuffer.clear();
+		encoder.reset();
+		encoder.encode(CharBuffer.wrap(str), byteBuffer, true);
+		byteBuffer.flip();
+		channel.write(byteBuffer);
+//		try {
+//			byteBuffer.clear();
+//			encoder.reset();
+//			encoder.encode(CharBuffer.wrap(str), byteBuffer, true);
+//			byteBuffer.flip();
+//			channel.write(byteBuffer);
+//		} catch (IOException ex) {
+//			ex.printStackTrace();
+//		}
 	}
 	
 	
@@ -165,7 +170,11 @@ public class JuliusClient
 					break;
 				} else {
 					String cmd = in + "\n"; 
-					client.send(cmd);
+					try {
+						client.send(cmd);
+					} catch (IOException e) {
+						e.printStackTrace();
+					}
 				}
 			}
 			try { Thread.sleep(1); } catch (Exception e) {}
