@@ -31,8 +31,10 @@ public class SubProcess {
 	private BufferedReader stderr;
 	private boolean running = false;
 	private String error_;
+	int maxCommandLength_ = 99999;
 	
 	public SubProcess() {
+		maxCommandLength_ = Property.getForPlatformAsInt( "SubProcess.MaxCommandLength", 99999);
 		error_ = "";
 	}
 	
@@ -102,8 +104,8 @@ public class SubProcess {
 			error_ += s;
 			return false;
 		}
-		if (Util.isWindows() && module_command.length() > 64){
-			String s = "SubProcess.run(): command too long for Windows:" + module_command;
+		if (module_command.length() > maxCommandLength_){
+			String s = "SubProcess.run(): command too long:" + module_command + "\n";
 			dbg.err(s);
 			error_ += s;
 			return false;
